@@ -14,18 +14,18 @@
 #include <tqlayout.h>
 #include <tqtimer.h>
 
-#include <klocale.h>
+#include <tdelocale.h>
 #include <kiconloader.h>
 #include <kurldrag.h>
-#include <kpopupmenu.h>
-#include <kaction.h>
-#include <kactioncollection.h>
-#include <kmessagebox.h>
+#include <tdepopupmenu.h>
+#include <tdeaction.h>
+#include <tdeactioncollection.h>
+#include <tdemessagebox.h>
 #include <kmountpoint.h>
 #include <kprogress.h>
 #include <kprocess.h>
 #include <kmimetype.h>
-#include <kapplication.h>
+#include <tdeapplication.h>
 #include <kuser.h>
 
 // TODO move listDir, addFiles, addDir, etc -- done?
@@ -34,7 +34,7 @@
 
 
 ReplayGainFileListItem::ReplayGainFileListItem( TQListView* parent )
-    : KListViewItem( parent )
+    : TDEListViewItem( parent )
 {
     m_type = File;
     mimeType = "application/octet-stream";
@@ -43,7 +43,7 @@ ReplayGainFileListItem::ReplayGainFileListItem( TQListView* parent )
 }
 
 // ReplayGainFileListItem::ReplayGainFileListItem( TQListView* parent, TQListViewItem* after )
-//     : KListViewItem( parent, after )
+//     : TDEListViewItem( parent, after )
 // {
 //     m_type = File;
 //     mimeType = "application/octet-stream";
@@ -52,7 +52,7 @@ ReplayGainFileListItem::ReplayGainFileListItem( TQListView* parent )
 // }
 
 ReplayGainFileListItem::ReplayGainFileListItem( ReplayGainFileListItem* parent )
-    : KListViewItem( parent )
+    : TDEListViewItem( parent )
 {
     m_type = File;
     mimeType = "application/octet-stream";
@@ -115,7 +115,7 @@ void ReplayGainFileListItem::paintCell( TQPainter *p, const TQColorGroup &cg, in
         return;
     }
 
-    KListViewItem::paintCell( p, _cg, column, width, alignment );
+    TDEListViewItem::paintCell( p, _cg, column, width, alignment );
 }
 
 void ReplayGainFileListItem::setType( Type type )
@@ -126,7 +126,7 @@ void ReplayGainFileListItem::setType( Type type )
 
     if( type == Album ) {
         setOpen( true );
-        setPixmap( 0, KGlobal::iconLoader()->loadIcon("cdrom_unmount",KIcon::Small) );
+        setPixmap( 0, TDEGlobal::iconLoader()->loadIcon("media-optical-cdrom",TDEIcon::Small) );
     }
 }
 
@@ -157,11 +157,11 @@ int ReplayGainFileListItem::compare( TQListViewItem* item, int column, bool asce
     // NOTE looking at the types, not the strings would be better
     if( text(1) == "" && item->text(1) != "" ) return -1;
     else if( text(1) != "" && item->text(1) == "" ) return 1;
-    else return KListViewItem::compare( item, column, ascending );
+    else return TDEListViewItem::compare( item, column, ascending );
 }
 
 ReplayGainFileList::ReplayGainFileList( TagEngine* _tagEngine, Config* _config, Logger* _logger, TQWidget *parent, const char *name )
-    : KListView( parent, name )
+    : TDEListView( parent, name )
 {
     tagEngine = _tagEngine;
     config = _config;
@@ -202,21 +202,21 @@ ReplayGainFileList::ReplayGainFileList( TagEngine* _tagEngine, Config* _config,
     grid->addWidget( pScanStatus, 1, 1 );
     grid->setColStretch( 1, 2 );
 
-    contextMenu = new KPopupMenu( this );
+    contextMenu = new TDEPopupMenu( this );
     connect( TQT_TQOBJECT(this), TQT_SIGNAL(contextMenuRequested(TQListViewItem*,const TQPoint&,int)),
                TQT_TQOBJECT(this), TQT_SLOT(showContextMenu(TQListViewItem*,const TQPoint&,int))
              );
 
     // we haven't got access to the action collection of soundKonverter, so let's create a new one
-    actionCollection = new KActionCollection( this );
+    actionCollection = new TDEActionCollection( this );
 
-    calc_gain = new KAction( i18n("Calculate Replay Gain tags"), "apply", 0, TQT_TQOBJECT(this), TQT_SLOT(calcSelectedItemsGain()), actionCollection, "calc_album" );
-    remove_gain = new KAction( i18n("Remove Replay Gain tags"), "cancel", 0, TQT_TQOBJECT(this), TQT_SLOT(removeSelectedItemsGain()), actionCollection, "remove_gain" );
-    remove = new KAction( i18n("Remove"), "edittrash", Key_Delete, TQT_TQOBJECT(this), TQT_SLOT(removeSelectedItems()), actionCollection, "remove" );
-    paste = new KAction( i18n("Paste"), "editpaste", 0, TQT_TQOBJECT(this), 0, actionCollection, "paste" );
-    newalbum = new KAction( i18n("New album"), "filenew", 0, TQT_TQOBJECT(this), TQT_SLOT(createNewAlbum()), actionCollection, "newalbum" );
-    open_albums = new KAction( i18n("Open all albums"), "view_tree", 0, TQT_TQOBJECT(this), TQT_SLOT(openAlbums()), actionCollection, "open_albums" );
-    close_albums = new KAction( i18n("Cloase all albums"), "view_text", 0, TQT_TQOBJECT(this), TQT_SLOT(closeAlbums()), actionCollection, "close_albums" );
+    calc_gain = new TDEAction( i18n("Calculate Replay Gain tags"), "apply", 0, TQT_TQOBJECT(this), TQT_SLOT(calcSelectedItemsGain()), actionCollection, "calc_album" );
+    remove_gain = new TDEAction( i18n("Remove Replay Gain tags"), "cancel", 0, TQT_TQOBJECT(this), TQT_SLOT(removeSelectedItemsGain()), actionCollection, "remove_gain" );
+    remove = new TDEAction( i18n("Remove"), "edittrash", Key_Delete, TQT_TQOBJECT(this), TQT_SLOT(removeSelectedItems()), actionCollection, "remove" );
+    paste = new TDEAction( i18n("Paste"), "edit-paste", 0, TQT_TQOBJECT(this), 0, actionCollection, "paste" );
+    newalbum = new TDEAction( i18n("New album"), "document-new", 0, TQT_TQOBJECT(this), TQT_SLOT(createNewAlbum()), actionCollection, "newalbum" );
+    open_albums = new TDEAction( i18n("Open all albums"), "view_tree", 0, TQT_TQOBJECT(this), TQT_SLOT(openAlbums()), actionCollection, "open_albums" );
+    close_albums = new TDEAction( i18n("Cloase all albums"), "view_text", 0, TQT_TQOBJECT(this), TQT_SLOT(closeAlbums()), actionCollection, "close_albums" );
 
     replayGain = new ReplayGain( config, logger );
 
@@ -236,15 +236,15 @@ ReplayGainFileList::ReplayGainFileList( TagEngine* _tagEngine, Config* _config,
                TQT_SLOT( slotDropped(TQDropEvent*, TQListViewItem*, TQListViewItem*) )
              );
 
-    process = new KProcess();
-    connect( process, TQT_SIGNAL(receivedStdout(KProcess*,char*,int)),
-               TQT_TQOBJECT(this), TQT_SLOT(processOutput(KProcess*,char*,int))
+    process = new TDEProcess();
+    connect( process, TQT_SIGNAL(receivedStdout(TDEProcess*,char*,int)),
+               TQT_TQOBJECT(this), TQT_SLOT(processOutput(TDEProcess*,char*,int))
              );
-    connect( process, TQT_SIGNAL(receivedStderr(KProcess*,char*,int)),
-               TQT_TQOBJECT(this), TQT_SLOT(processOutput(KProcess*,char*,int))
+    connect( process, TQT_SIGNAL(receivedStderr(TDEProcess*,char*,int)),
+               TQT_TQOBJECT(this), TQT_SLOT(processOutput(TDEProcess*,char*,int))
              );
-    connect( process, TQT_SIGNAL(processExited(KProcess*)),
-               TQT_TQOBJECT(this), TQT_SLOT(processExit(KProcess*))
+    connect( process, TQT_SIGNAL(processExited(TDEProcess*)),
+               TQT_TQOBJECT(this), TQT_SLOT(processExit(TDEProcess*))
              );
 
     tUpdateProgress = new TQTimer( this, "tUpdateProgress" );
@@ -268,7 +268,7 @@ int ReplayGainFileList::columnByName( const TQString& name )
 
 void ReplayGainFileList::viewportPaintEvent( TQPaintEvent* e )
 {
-    KListView::viewportPaintEvent( e );
+    TDEListView::viewportPaintEvent( e );
 
     // the bubble help
     if( childCount() == 0 ) {
@@ -340,8 +340,8 @@ void ReplayGainFileList::contentsDragMoveEvent( TQDragMoveEvent *e )
         cleanItemHighlighter();
         cleanDropVisualizer();
 
-        // the rest is handled by KListView
-        KListView::contentsDragMoveEvent( e );
+        // the rest is handled by TDEListView
+        TDEListView::contentsDragMoveEvent( e );
 
         return;
     }
@@ -364,8 +364,8 @@ void ReplayGainFileList::contentsDragMoveEvent( TQDragMoveEvent *e )
         cleanItemHighlighter();
     }
 
-    // the rest is handled by KListView
-    KListView::contentsDragMoveEvent( e );
+    // the rest is handled by TDEListView
+    TDEListView::contentsDragMoveEvent( e );
 }
 
 void ReplayGainFileList::contentsDropEvent( TQDropEvent *e )
@@ -619,7 +619,7 @@ void ReplayGainFileList::addFile( const TQString& file )
 
         for( KMountPoint::List::ConstIterator jt = mountPoints.begin(); jt != mountPoints.end(); ++jt )
         {
-            const KSharedPtr<KMountPoint> mp = *jt;
+            const TDESharedPtr<KMountPoint> mp = *jt;
             if( mp->mountedFrom() == device )
             {
                 filePathName = ( mp->mountPoint() == "/" ) ? mp->mountPoint() : mp->mountPoint() + "/";
@@ -1129,7 +1129,7 @@ void ReplayGainFileList::processNextFile()
     emit processStopped();
 }
 
-void ReplayGainFileList::processOutput( KProcess* proc, char* data, int )
+void ReplayGainFileList::processOutput( TDEProcess* proc, char* data, int )
 {
     int iPercent = 0, iTime = 0, iPos = 0, iNum = 0;
 
@@ -1192,7 +1192,7 @@ void ReplayGainFileList::processOutput( KProcess* proc, char* data, int )
     }
 }
 
-void ReplayGainFileList::processExit( KProcess* proc )
+void ReplayGainFileList::processExit( TDEProcess* proc )
 {
     logger->processCompleted( logID, ( proc->signalled() ) ? -1 : 0 );
 
